# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['panos_util']

package_data = \
{'': ['*']}

install_requires = \
['pan-python>=0.16.0,<0.17.0', 'xlsxwriter>=1.3.3,<4.0.0']

entry_points = \
{'console_scripts': ['block_progress_report = panos_util.block_report:main',
                     'threat_signature_report = panos_util.threat_report:main']}

setup_kwargs = {
    'name': 'panos-ips-reports',
    'version': '2.0.1',
    'description': 'Additional IPS reports for Palo Alto Networks firewalls',
    'long_description': '# Palo Alto IPS Reporting Scripts\n\n![CI/CD](https://github.com/mrichardson03/panos-ips-reports/workflows/CI/CD/badge.svg)\n\nAdditional IPS reports for Palo Alto Networks firewalls.\n\n## Requirements\n\n- Python 3.7+\n\n## Installation\n\nInstall from PyPI using pip:\n\n```bash\npip3 install panos-ips-reports\n```\n\nUpgrade to the latest version:\n\n```bash\npip3 install --upgrade panos-ips-reports\n```\n\n`pip` will install the required Python modules, and add the scripts supplied by this\npackage to your system path.\n\n## Included Scripts\n\n### block_progress_report\n\nProduces a report on the number of rules blocking critical, high, and medium\nthreats using a Panorama tech support file as input.\n\n#### Usage\n\n```bash\n$ block_progress_report <input_file> <output_file>\n```\n\n##### Required Arguments\n\n- `input_file` - Panorama tech support file.\n- `output_file` - Excel file containing report.\n\n##### Example\n\n```bash\n$ block_progress_report ~/Downloads/20200901_1817_techsupport.tgz block_report.xlsx\n```\n\n### threat_signature_report\n\nProduces a report on all the threat signatures in the current content version\nof a firewall or Panorama.\n\n#### Usage\n\n```bash\n$ threat_signature_report [-k | --api_key ] <hostname> <output_file>\n```\n\n##### Required Arguments\n\n- `hostname` - Firewall or Panorama device to pull threat signatures from.\n- `output_file` - Excel file containing report.\n\n##### Optional Arguments\n\n- `api_key` - API key to use for connection.  If this option is not specified,\nthe user will be prompted for the username and password to use.\n\n##### Example\n\n```bash\n$ threat_signature_report 192.168.55.5 threat_sig_report.xlsx\n```',
    'author': 'Michael Richardson',
    'author_email': 'mrichardson03@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/mrichardson03/panos-ips-reports',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
